aboutsummaryrefslogtreecommitdiff
path: root/samples
diff options
context:
space:
mode:
Diffstat (limited to 'samples')
-rw-r--r--samples/client.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/samples/client.c b/samples/client.c
index c492854..6cd065d 100644
--- a/samples/client.c
+++ b/samples/client.c
@@ -1250,12 +1250,12 @@ int main(int argc, char *argv[])
}
/*
* Schedule an interrupt in 3 seconds from now in the old server and then
* immediatelly migrate the device. The new server should deliver the
* interrupt. Hopefully 3 seconds should be enough for migration to finish.
* TODO make this value a command line option.
*/
- t = time(NULL) + 3;
+ t = time(NULL) + 10;
ret = access_region(sock, VFU_PCI_DEV_BAR0_REGION_IDX, true, 0, &t, sizeof(t));
if (ret < 0) {
err(EXIT_FAILURE, "failed to write to BAR0");
@@ -1250,12 +1250,12 @@ int main(int argc, char *argv[])
}
/*
- * Schedule an interrupt in 3 seconds from now in the old server and then
+ * Schedule an interrupt in 10 seconds from now in the old server and then
* immediatelly migrate the device. The new server should deliver the
@@ -1250,12 +1250,12 @@ int main(int argc, char *argv[])
* immediatelly migrate the device. The new server should deliver the
- * interrupt. Hopefully 3 seconds should be enough for migration to finish.
+ * interrupt. Hopefully 10 seconds should be enough for migration to finish.
* TODO make this value a command line option.
*/